Class: Google::Apis::SolarV1::BuildingInsights
- Inherits:
-
Object
- Object
- Google::Apis::SolarV1::BuildingInsights
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/solar_v1/classes.rb,
lib/google/apis/solar_v1/representations.rb,
lib/google/apis/solar_v1/representations.rb
Overview
Response message for Solar.FindClosestBuildingInsights. Information about
the location, dimensions, and solar potential of a building.
Instance Attribute Summary collapse
-
#administrative_area ⇒ String
Administrative area 1 (e.g., in the US, the state) that contains this building.
-
#bounding_box ⇒ Google::Apis::SolarV1::LatLngBox
A bounding box in lat/lng coordinates.
-
#center ⇒ Google::Apis::SolarV1::LatLng
An object that represents a latitude/longitude pair.
-
#detected_arrays ⇒ Google::Apis::SolarV1::BuildingInsightsDetectedArrays
Information about solar arrays detected on the building.
-
#imagery_date ⇒ Google::Apis::SolarV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#imagery_processed_date ⇒ Google::Apis::SolarV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#imagery_quality ⇒ String
The quality of the imagery used to compute the data for this building.
-
#name ⇒ String
The resource name for the building, of the format
buildings/place_id``. -
#postal_code ⇒ String
Postal code (e.g., US zip code) this building is contained by.
-
#region_code ⇒ String
Region code for the country (or region) this building is in.
-
#solar_potential ⇒ Google::Apis::SolarV1::SolarPotential
Information about the solar potential of a building.
-
#statistical_area ⇒ String
Statistical area (e.g., US census tract) this building is in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BuildingInsights
constructor
A new instance of BuildingInsights.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BuildingInsights
Returns a new instance of BuildingInsights.
111 112 113 |
# File 'lib/google/apis/solar_v1/classes.rb', line 111 def initialize(**args) update!(**args) end |
Instance Attribute Details
#administrative_area ⇒ String
Administrative area 1 (e.g., in the US, the state) that contains this building.
For example, in the US, the abbreviation might be "MA" or "CA."
Corresponds to the JSON property administrativeArea
34 35 36 |
# File 'lib/google/apis/solar_v1/classes.rb', line 34 def administrative_area @administrative_area end |
#bounding_box ⇒ Google::Apis::SolarV1::LatLngBox
A bounding box in lat/lng coordinates.
Corresponds to the JSON property boundingBox
39 40 41 |
# File 'lib/google/apis/solar_v1/classes.rb', line 39 def bounding_box @bounding_box end |
#center ⇒ Google::Apis::SolarV1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property center
47 48 49 |
# File 'lib/google/apis/solar_v1/classes.rb', line 47 def center @center end |
#detected_arrays ⇒ Google::Apis::SolarV1::BuildingInsightsDetectedArrays
Information about solar arrays detected on the building.
Corresponds to the JSON property detectedArrays
52 53 54 |
# File 'lib/google/apis/solar_v1/classes.rb', line 52 def detected_arrays @detected_arrays end |
#imagery_date ⇒ Google::Apis::SolarV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property imageryDate
64 65 66 |
# File 'lib/google/apis/solar_v1/classes.rb', line 64 def imagery_date @imagery_date end |
#imagery_processed_date ⇒ Google::Apis::SolarV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property imageryProcessedDate
76 77 78 |
# File 'lib/google/apis/solar_v1/classes.rb', line 76 def imagery_processed_date @imagery_processed_date end |
#imagery_quality ⇒ String
The quality of the imagery used to compute the data for this building.
Corresponds to the JSON property imageryQuality
81 82 83 |
# File 'lib/google/apis/solar_v1/classes.rb', line 81 def imagery_quality @imagery_quality end |
#name ⇒ String
The resource name for the building, of the format buildings/place_id`.
Corresponds to the JSON propertyname`
86 87 88 |
# File 'lib/google/apis/solar_v1/classes.rb', line 86 def name @name end |
#postal_code ⇒ String
Postal code (e.g., US zip code) this building is contained by.
Corresponds to the JSON property postalCode
91 92 93 |
# File 'lib/google/apis/solar_v1/classes.rb', line 91 def postal_code @postal_code end |
#region_code ⇒ String
Region code for the country (or region) this building is in.
Corresponds to the JSON property regionCode
96 97 98 |
# File 'lib/google/apis/solar_v1/classes.rb', line 96 def region_code @region_code end |
#solar_potential ⇒ Google::Apis::SolarV1::SolarPotential
Information about the solar potential of a building. A number of fields in
this are defined in terms of "panels". The fields panel_capacity_watts,
panel_height_meters, and panel_width_meters describe the parameters of the
model of panel used in these calculations.
Corresponds to the JSON property solarPotential
104 105 106 |
# File 'lib/google/apis/solar_v1/classes.rb', line 104 def solar_potential @solar_potential end |
#statistical_area ⇒ String
Statistical area (e.g., US census tract) this building is in.
Corresponds to the JSON property statisticalArea
109 110 111 |
# File 'lib/google/apis/solar_v1/classes.rb', line 109 def statistical_area @statistical_area end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/google/apis/solar_v1/classes.rb', line 116 def update!(**args) @administrative_area = args[:administrative_area] if args.key?(:administrative_area) @bounding_box = args[:bounding_box] if args.key?(:bounding_box) @center = args[:center] if args.key?(:center) @detected_arrays = args[:detected_arrays] if args.key?(:detected_arrays) @imagery_date = args[:imagery_date] if args.key?(:imagery_date) @imagery_processed_date = args[:imagery_processed_date] if args.key?(:imagery_processed_date) @imagery_quality = args[:imagery_quality] if args.key?(:imagery_quality) @name = args[:name] if args.key?(:name) @postal_code = args[:postal_code] if args.key?(:postal_code) @region_code = args[:region_code] if args.key?(:region_code) @solar_potential = args[:solar_potential] if args.key?(:solar_potential) @statistical_area = args[:statistical_area] if args.key?(:statistical_area) end |