Class: Google::Apis::SolarV1::BuildingInsightsDetectedArrays

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/solar_v1/classes.rb,
lib/google/apis/solar_v1/representations.rb,
lib/google/apis/solar_v1/representations.rb

Overview

Information about solar arrays detected on the building.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BuildingInsightsDetectedArrays

Returns a new instance of BuildingInsightsDetectedArrays.



153
154
155
# File 'lib/google/apis/solar_v1/classes.rb', line 153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detection_statusString

Indicates the detection status of solar arrays for this building. Corresponds to the JSON property detectionStatus

Returns:

  • (String)


139
140
141
# File 'lib/google/apis/solar_v1/classes.rb', line 139

def detection_status
  @detection_status
end

#latest_capture_dateGoogle::Apis::SolarV1::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property latestCaptureDate



151
152
153
# File 'lib/google/apis/solar_v1/classes.rb', line 151

def latest_capture_date
  @latest_capture_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



158
159
160
161
# File 'lib/google/apis/solar_v1/classes.rb', line 158

def update!(**args)
  @detection_status = args[:detection_status] if args.key?(:detection_status)
  @latest_capture_date = args[:latest_capture_date] if args.key?(:latest_capture_date)
end