Class: Google::Apis::SolarV1::FinancedPurchaseSavings
- Inherits:
-
Object
- Object
- Google::Apis::SolarV1::FinancedPurchaseSavings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/solar_v1/classes.rb,
lib/google/apis/solar_v1/representations.rb,
lib/google/apis/solar_v1/representations.rb
Overview
Cost and benefit of using a loan to buy a particular configuration of solar panels with a particular electricity usage.
Instance Attribute Summary collapse
-
#annual_loan_payment ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
-
#loan_interest_rate ⇒ Float
The interest rate on loans assumed in this set of calculations.
-
#rebate_value ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
-
#savings ⇒ Google::Apis::SolarV1::SavingsOverTime
Financial information that's shared between different financing methods.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FinancedPurchaseSavings
constructor
A new instance of FinancedPurchaseSavings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FinancedPurchaseSavings
Returns a new instance of FinancedPurchaseSavings.
393 394 395 |
# File 'lib/google/apis/solar_v1/classes.rb', line 393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annual_loan_payment ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property annualLoanPayment
376 377 378 |
# File 'lib/google/apis/solar_v1/classes.rb', line 376 def annual_loan_payment @annual_loan_payment end |
#loan_interest_rate ⇒ Float
The interest rate on loans assumed in this set of calculations.
Corresponds to the JSON property loanInterestRate
381 382 383 |
# File 'lib/google/apis/solar_v1/classes.rb', line 381 def loan_interest_rate @loan_interest_rate end |
#rebate_value ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property rebateValue
386 387 388 |
# File 'lib/google/apis/solar_v1/classes.rb', line 386 def rebate_value @rebate_value end |
#savings ⇒ Google::Apis::SolarV1::SavingsOverTime
Financial information that's shared between different financing methods.
Corresponds to the JSON property savings
391 392 393 |
# File 'lib/google/apis/solar_v1/classes.rb', line 391 def savings @savings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
398 399 400 401 402 403 |
# File 'lib/google/apis/solar_v1/classes.rb', line 398 def update!(**args) @annual_loan_payment = args[:annual_loan_payment] if args.key?(:annual_loan_payment) @loan_interest_rate = args[:loan_interest_rate] if args.key?(:loan_interest_rate) @rebate_value = args[:rebate_value] if args.key?(:rebate_value) @savings = args[:savings] if args.key?(:savings) end |