Class: Google::Apis::SolarV1::LeasingSavings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/solar_v1/classes.rb,
lib/google/apis/solar_v1/representations.rb,
lib/google/apis/solar_v1/representations.rb

Overview

Cost and benefit of leasing a particular configuration of solar panels with a particular electricity usage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LeasingSavings

Returns a new instance of LeasingSavings.



702
703
704
# File 'lib/google/apis/solar_v1/classes.rb', line 702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annual_leasing_costGoogle::Apis::SolarV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property annualLeasingCost



677
678
679
# File 'lib/google/apis/solar_v1/classes.rb', line 677

def annual_leasing_cost
  @annual_leasing_cost
end

#leases_allowedBoolean Also known as: leases_allowed?

Whether leases are allowed in this juristiction (leases are not allowed in some states). If this field is false, then the values in this message should probably be ignored. Corresponds to the JSON property leasesAllowed

Returns:

  • (Boolean)


684
685
686
# File 'lib/google/apis/solar_v1/classes.rb', line 684

def leases_allowed
  @leases_allowed
end

#leases_supportedBoolean Also known as: leases_supported?

Whether leases are supported in this juristiction by the financial calculation engine. If this field is false, then the values in this message should probably be ignored. This is independent of leases_allowed: in some areas leases are allowed, but under conditions that aren't handled by the financial models. Corresponds to the JSON property leasesSupported

Returns:

  • (Boolean)


694
695
696
# File 'lib/google/apis/solar_v1/classes.rb', line 694

def leases_supported
  @leases_supported
end

#savingsGoogle::Apis::SolarV1::SavingsOverTime

Financial information that's shared between different financing methods. Corresponds to the JSON property savings



700
701
702
# File 'lib/google/apis/solar_v1/classes.rb', line 700

def savings
  @savings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



707
708
709
710
711
712
# File 'lib/google/apis/solar_v1/classes.rb', line 707

def update!(**args)
  @annual_leasing_cost = args[:annual_leasing_cost] if args.key?(:annual_leasing_cost)
  @leases_allowed = args[:leases_allowed] if args.key?(:leases_allowed)
  @leases_supported = args[:leases_supported] if args.key?(:leases_supported)
  @savings = args[:savings] if args.key?(:savings)
end