Class: Google::Apis::SolarV1::RoofSegmentSummary
- Inherits:
-
Object
- Object
- Google::Apis::SolarV1::RoofSegmentSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/solar_v1/classes.rb,
lib/google/apis/solar_v1/representations.rb,
lib/google/apis/solar_v1/representations.rb
Overview
Information about a roof segment on the building, with some number of panels placed on it.
Instance Attribute Summary collapse
-
#azimuth_degrees ⇒ Float
Compass direction the roof segment is pointing in.
-
#panels_count ⇒ Fixnum
The total number of panels on this segment.
-
#pitch_degrees ⇒ Float
Angle of the roof segment relative to the theoretical ground plane.
-
#segment_index ⇒ Fixnum
Index in roof_segment_stats of the corresponding
RoofSegmentSizeAndSunshineStats. -
#yearly_energy_dc_kwh ⇒ Float
How much sunlight energy this part of the layout captures over the course of a year, in DC kWh, assuming the panels described above.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoofSegmentSummary
constructor
A new instance of RoofSegmentSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoofSegmentSummary
Returns a new instance of RoofSegmentSummary.
843 844 845 |
# File 'lib/google/apis/solar_v1/classes.rb', line 843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#azimuth_degrees ⇒ Float
Compass direction the roof segment is pointing in. 0 = North, 90 = East, 180 =
South. For a "flat" roof segment (pitch_degrees very near 0), azimuth is not
well defined, so for consistency, we define it arbitrarily to be 0 (North).
Corresponds to the JSON property azimuthDegrees
818 819 820 |
# File 'lib/google/apis/solar_v1/classes.rb', line 818 def azimuth_degrees @azimuth_degrees end |
#panels_count ⇒ Fixnum
The total number of panels on this segment.
Corresponds to the JSON property panelsCount
823 824 825 |
# File 'lib/google/apis/solar_v1/classes.rb', line 823 def panels_count @panels_count end |
#pitch_degrees ⇒ Float
Angle of the roof segment relative to the theoretical ground plane. 0 =
parallel to the ground, 90 = perpendicular to the ground.
Corresponds to the JSON property pitchDegrees
829 830 831 |
# File 'lib/google/apis/solar_v1/classes.rb', line 829 def pitch_degrees @pitch_degrees end |
#segment_index ⇒ Fixnum
Index in roof_segment_stats of the corresponding
RoofSegmentSizeAndSunshineStats.
Corresponds to the JSON property segmentIndex
835 836 837 |
# File 'lib/google/apis/solar_v1/classes.rb', line 835 def segment_index @segment_index end |
#yearly_energy_dc_kwh ⇒ Float
How much sunlight energy this part of the layout captures over the course of a
year, in DC kWh, assuming the panels described above.
Corresponds to the JSON property yearlyEnergyDcKwh
841 842 843 |
# File 'lib/google/apis/solar_v1/classes.rb', line 841 def yearly_energy_dc_kwh @yearly_energy_dc_kwh end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
848 849 850 851 852 853 854 |
# File 'lib/google/apis/solar_v1/classes.rb', line 848 def update!(**args) @azimuth_degrees = args[:azimuth_degrees] if args.key?(:azimuth_degrees) @panels_count = args[:panels_count] if args.key?(:panels_count) @pitch_degrees = args[:pitch_degrees] if args.key?(:pitch_degrees) @segment_index = args[:segment_index] if args.key?(:segment_index) @yearly_energy_dc_kwh = args[:yearly_energy_dc_kwh] if args.key?(:yearly_energy_dc_kwh) end |