Class: Google::Apis::SolarV1::LatLngBox
- Inherits:
-
Object
- Object
- Google::Apis::SolarV1::LatLngBox
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/solar_v1/classes.rb,
lib/google/apis/solar_v1/representations.rb,
lib/google/apis/solar_v1/representations.rb
Overview
A bounding box in lat/lng coordinates.
Instance Attribute Summary collapse
-
#ne ⇒ Google::Apis::SolarV1::LatLng
An object that represents a latitude/longitude pair.
-
#sw ⇒ Google::Apis::SolarV1::LatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LatLngBox
constructor
A new instance of LatLngBox.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LatLngBox
Returns a new instance of LatLngBox.
658 659 660 |
# File 'lib/google/apis/solar_v1/classes.rb', line 658 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ne ⇒ Google::Apis::SolarV1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property ne
648 649 650 |
# File 'lib/google/apis/solar_v1/classes.rb', line 648 def ne @ne end |
#sw ⇒ Google::Apis::SolarV1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property sw
656 657 658 |
# File 'lib/google/apis/solar_v1/classes.rb', line 656 def sw @sw end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
663 664 665 666 |
# File 'lib/google/apis/solar_v1/classes.rb', line 663 def update!(**args) @ne = args[:ne] if args.key?(:ne) @sw = args[:sw] if args.key?(:sw) end |