Class: Google::Apis::SolarV1::SavingsOverTime
- Inherits:
-
Object
- Object
- Google::Apis::SolarV1::SavingsOverTime
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/solar_v1/classes.rb,
lib/google/apis/solar_v1/representations.rb,
lib/google/apis/solar_v1/representations.rb
Overview
Financial information that's shared between different financing methods.
Instance Attribute Summary collapse
-
#financially_viable ⇒ Boolean
(also: #financially_viable?)
Indicates whether this scenario is financially viable.
-
#present_value_of_savings_lifetime ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
-
#present_value_of_savings_year20 ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
-
#savings_lifetime ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
-
#savings_year1 ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
-
#savings_year20 ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavingsOverTime
constructor
A new instance of SavingsOverTime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavingsOverTime
Returns a new instance of SavingsOverTime.
893 894 895 |
# File 'lib/google/apis/solar_v1/classes.rb', line 893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#financially_viable ⇒ Boolean Also known as: financially_viable?
Indicates whether this scenario is financially viable. Will be false for
scenarios with poor financial viability (e.g., money-losing).
Corresponds to the JSON property financiallyViable
865 866 867 |
# File 'lib/google/apis/solar_v1/classes.rb', line 865 def financially_viable @financially_viable end |
#present_value_of_savings_lifetime ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property presentValueOfSavingsLifetime
871 872 873 |
# File 'lib/google/apis/solar_v1/classes.rb', line 871 def present_value_of_savings_lifetime @present_value_of_savings_lifetime end |
#present_value_of_savings_year20 ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property presentValueOfSavingsYear20
876 877 878 |
# File 'lib/google/apis/solar_v1/classes.rb', line 876 def present_value_of_savings_year20 @present_value_of_savings_year20 end |
#savings_lifetime ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property savingsLifetime
881 882 883 |
# File 'lib/google/apis/solar_v1/classes.rb', line 881 def savings_lifetime @savings_lifetime end |
#savings_year1 ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property savingsYear1
886 887 888 |
# File 'lib/google/apis/solar_v1/classes.rb', line 886 def savings_year1 @savings_year1 end |
#savings_year20 ⇒ Google::Apis::SolarV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property savingsYear20
891 892 893 |
# File 'lib/google/apis/solar_v1/classes.rb', line 891 def savings_year20 @savings_year20 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
898 899 900 901 902 903 904 905 |
# File 'lib/google/apis/solar_v1/classes.rb', line 898 def update!(**args) @financially_viable = args[:financially_viable] if args.key?(:financially_viable) @present_value_of_savings_lifetime = args[:present_value_of_savings_lifetime] if args.key?(:present_value_of_savings_lifetime) @present_value_of_savings_year20 = args[:present_value_of_savings_year20] if args.key?(:present_value_of_savings_year20) @savings_lifetime = args[:savings_lifetime] if args.key?(:savings_lifetime) @savings_year1 = args[:savings_year1] if args.key?(:savings_year1) @savings_year20 = args[:savings_year20] if args.key?(:savings_year20) end |